Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2305)

Unified Diff: chrome/browser/ui/cocoa/browser_window_controller.mm

Issue 10885024: Integrate Chrome To Mobile with Action Box UI. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Disable ShowChromeToMobileBubble on GTK. Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/cocoa/browser_window_controller.mm
diff --git a/chrome/browser/ui/cocoa/browser_window_controller.mm b/chrome/browser/ui/cocoa/browser_window_controller.mm
index c650777b21fcce8d1dc245f41ec27180e2aa593d..8688cd830e0f6e02754f86771db3591c7f3be9cd 100644
--- a/chrome/browser/ui/cocoa/browser_window_controller.mm
+++ b/chrome/browser/ui/cocoa/browser_window_controller.mm
@@ -77,6 +77,7 @@
#include "content/public/browser/render_widget_host_view.h"
#include "content/public/browser/web_contents.h"
#include "grit/generated_resources.h"
+#include "grit/theme_resources.h"
#include "grit/locale_settings.h"
#include "ui/base/l10n/l10n_util.h"
#include "ui/base/l10n/l10n_util_mac.h"
@@ -1648,10 +1649,6 @@ enum {
bookmarkBubbleController_ = nil;
}
-- (NSPoint)chromeToMobileBubblePoint {
- return [toolbarController_ chromeToMobileBubblePoint];
-}
-
// Show the Chrome To Mobile bubble (e.g. user just clicked on the icon).
- (void)showChromeToMobileBubble {
// Do nothing if the bubble is already showing.
@@ -1670,7 +1667,7 @@ enum {
name:NSWindowWillCloseNotification
object:[chromeToMobileBubbleController_ window]];
sail 2012/08/29 22:29:51 can you add a DCHECK() for window. If this is ever
msw 2012/08/29 23:11:57 Done (moved to ChromeToMobileBubbleController show
// Show the lit Chrome To Mobile icon while the bubble is visible.
- [self locationBarBridge]->SetChromeToMobileDecorationLit(true);
+ [self locationBarBridge]->SetActionBoxIcon(IDR_MOBILE_LIT);
}
// Nil out the weak Chrome To Mobile bubble controller reference.
@@ -1682,8 +1679,8 @@ enum {
name:NSWindowWillCloseNotification
object:[chromeToMobileBubbleController_ window]];
sail 2012/08/29 22:29:51 same, need DCHECK
msw 2012/08/29 23:11:57 Done (moved to ChromeToMobileBubbleController wind
chromeToMobileBubbleController_ = nil;
- // Restore the dimmed Chrome To Mobile icon when the bubble closes.
- [self locationBarBridge]->SetChromeToMobileDecorationLit(false);
+ // Restore the Action Box icon when the bubble closes.
+ [self locationBarBridge]->SetActionBoxIcon(IDR_ACTION_BOX_BUTTON);
}
// Handle the editBookmarkNode: action sent from bookmark bubble controllers.

Powered by Google App Engine
This is Rietveld 408576698